package Sah::Schemas::Git;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-20'; # DATE
our $DIST = 'Sah-Schemas-Git'; # DIST
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Sah schemas related to git

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::Git - Sah schemas related to git

=head1 VERSION

This document describes version 0.004 of Sah::Schemas::Git (from Perl distribution Sah-Schemas-Git), released on 2021-07-20.

=head1 SYNOPSIS

=head1 CONTRIBUTOR

=for stopwords perlancar (on netbook-dell-xps13)

perlancar (on netbook-dell-xps13) <perlancar@gmail.com>

=head1 SAH SCHEMAS

=over

=item * L<git::refname|Sah::Schema::git::refname>

git reference name.

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Git>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Git>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Git>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
